@@ -1,8 +1,9 @@
 #include "bonusdisciplinewindow.h"
 #include "ui_bonusdisciplinewindow.h"
 #include <QPushButton>
+#include "ruleswindow.h"
 
-BonusDisciplineWindow::BonusDisciplineWindow(QWidget *parent, int serie, Player* player) :
+BonusDisciplineWindow::BonusDisciplineWindow(QWidget *parent, Book* book, Player* player) :
     QDialog(parent),
     ui(new Ui::BonusDisciplineWindow)
 {
@@ -13,7 +14,8 @@ BonusDisciplineWindow::BonusDisciplineWindow(QWidget *parent, int serie, Player*
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice, true);
     connect(m_RandomPicker, SIGNAL(Random(int)), SLOT(GetRandomSlot(int)));
 
-    m_Serie = serie;
+    m_Book = book;
+    m_Serie = m_Book->GetSerie();
     m_Player = player;
 
     switch (m_Serie){
@@ -48,8 +50,10 @@ void BonusDisciplineWindow::ShowData()
     foreach (KaiDiscipline* d, m_List){
         if (!m_Player->HasDiscipline(d->Name)){
             QLabel* lbl = new QLabel(this);
-            lbl->setText(d->Description());
+            lbl->setText(QString("<a href=\"%1\">%2</a>").arg(d->Name.toLower().replace(" ", ""))
+                                                         .arg(d->Description()));
             ui->layKaiDisciplines->addWidget(lbl, row, 0);
+            connect(lbl, SIGNAL(linkActivated(QString)), this, SLOT(DiscipleLinkSlot(QString)));
 
             bool done = false;
             QPushButton* pbn = new QPushButton(this);
@@ -148,3 +152,10 @@ void BonusDisciplineWindow::GetRandomSlot(int random)
     }
     ShowData();
 }
+
+void BonusDisciplineWindow::DiscipleLinkSlot(QString link)
+{
+    RulesWindow* dlg = new RulesWindow(this, m_Book->BaseDirectory);
+    dlg->show();
+    dlg->ScrollToAnchor(link);
+}
