@@ -960,6 +960,14 @@ QString BookWindow::ChooseItem(QString title)
     return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
 }
 
+QString BookWindow::ChooseItemExceptMeals(QString title)
+{
+    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseItemExceptMeals);
+    dlg->setWindowTitle(title);
+    dlg->exec();
+    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+}
+
 QString BookWindow::ChooseSpecialItem(QString title)
 {
     ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseSpecialItem);
