@@ -74,6 +74,9 @@ public slots:
     void Equip() { if (GetCanBeEquipped()) SetIsEquipped(true); }
     void Unequip() { SetIsEquipped(false); }
 
+    bool GetIsArrow() { return GetBoolProperty("IsArrow"); }
+    void SetIsArrow(bool value) { SetBoolProperty("IsArrow", value); }
+
     bool GetIsWeapon() { return GetBoolProperty("IsWeapon"); }
     void SetIsWeapon(bool value) { SetBoolProperty("IsWeapon", value); }
 
@@ -105,7 +108,8 @@ public:
        Axe,
        Sword,
        Quarterstaff,
-       Broadsword
+       Broadsword,
+       Bow
     };
 
     explicit Weapon(QObject *parent = 0);
