@@ -31,7 +31,7 @@ FightWindow::FightWindow(QWidget *parent, Player* player, Enemy* enemy, bool can
 #endif
 
     m_Close = false;
-    m_PointsLost = 0;
+    m_PlayerPointsLost = 0;
     m_EnemyPointsLost = 0;
     m_Round = 0;
     m_SurpriseRound = 0;
@@ -189,12 +189,16 @@ void FightWindow::Evaluate(int number)
     QStringList subele = ele.at(number - 1).split(";");
 
     QString message;
+    bool enemyDamage = false;
+    bool playerDamage = false;
+    m_EnemyDamage = 0;
+    m_PlayerDamage = 0;
     if (!m_Evaded){
+        enemyDamage = true;
         if (subele.at(0) == "k"){
-            m_Enemy->Endurance = 0;
-            m_EnemyPointsLost += m_Enemy->Endurance;
+            m_EnemyDamage = m_Enemy->Endurance;
         }else{
-            int enemyDamage = subele.at(0).toInt() * m_AttackMultiplier + m_AttackBonus;
+            m_EnemyDamage = subele.at(0).toInt() * m_AttackMultiplier + m_AttackBonus;
             if (m_Enemy->WoundedBy.count() > 0){
                 bool canHit = false;
                 foreach(QString w, m_Enemy->WoundedBy){
@@ -204,38 +208,44 @@ void FightWindow::Evaluate(int number)
                     }
                 }
                 if (!canHit)
-                    enemyDamage = 0;
+                    m_EnemyDamage = 0;
             }
 
-            m_Enemy->Endurance -= enemyDamage;
-            m_EnemyPointsLost += enemyDamage;
-            if (!m_Enemy->IsDead())
-                message.append(QString("%1 lost <b>%2</b> endurance points.<br>").arg(m_Enemy->Name).arg(enemyDamage));
-        }
-        if (m_Enemy->IsDead()){
-            message.append(QString("%1 was <b>killed</b>.<br>").arg(m_Enemy->Name));
-            ui->lblDice->setText("<font color=\"green\">You won!</font>");
         }
     }
 
     if (m_Round + 1 > m_SurpriseRound){
-        if (subele.at(1) == "k"){
-            m_Player->Endurance = 0;
-            m_PointsLost += m_Player->Endurance;
-        }else{
-            int playerDamage = subele.at(1).toInt();
-            if (playerDamage > m_Player->Endurance)
-                m_PointsLost += m_Player->Endurance;
-            else
-                m_PointsLost += playerDamage;
-            m_Player->Endurance -= playerDamage;
-            if (!m_Player->IsDead())
-                message.append(QString("You lost <b>%1</b> endurance points").arg(subele.at(1)));
-        }
+        playerDamage = true;
+        if (subele.at(1) == "k")
+            m_PlayerDamage = m_Player->Endurance;
+        else
+            m_PlayerDamage = subele.at(1).toInt();
+
+        if (m_PlayerDamage > m_Player->Endurance)
+            m_PlayerDamage = m_Player->Endurance;
+    }
+
+    if(!m_Enemy->DamageScript.isEmpty())
+        ExecuteScript("DamageScript", m_Enemy->DamageScript);
+
+    if (enemyDamage){
+        m_Enemy->Endurance -= m_EnemyDamage;
+        m_EnemyPointsLost += m_EnemyDamage;
+        if (m_Enemy->IsDead()){
+            message.append(QString("%1 was <b>killed</b>.<br>").arg(m_Enemy->Name));
+            ui->lblDice->setText("<font color=\"green\">You won!</font>");
+        }else
+            message.append(QString("%1 lost <b>%2</b> endurance points.<br>").arg(m_Enemy->Name).arg(m_EnemyDamage));
+    }
+
+    if (playerDamage){
+        m_Player->Endurance -= m_PlayerDamage;
+        m_PlayerPointsLost += m_EnemyDamage;
         if (m_Player->IsDead()){
             message.append("You were <b>killed</b>");
             ui->lblDice->setText("<font color=\"red\">You lost!</font>");
-        }
+        }else
+            message.append(QString("You lost <b>%1</b> endurance points").arg(subele.at(1)));
     }
 
     if (m_Player->Endurance < 0)
@@ -299,7 +309,7 @@ int FightWindow::GetRound()
 
 int FightWindow::GetLostEndurancePoints()
 {
-    return m_PointsLost;
+    return m_PlayerPointsLost;
 }
 
 int FightWindow::GetRandomNumber()
