@@ -16,9 +16,12 @@ public:
     ~RulesWindow();
 
     void ScrollToAnchor(QString anchor);
+    void show();
 
 private:
     Ui::RulesWindow *ui;
+
+    QString m_BookDirectory;
 };
 
 #endif // RULESWINDOW_H
